@@ -89,7 +89,7 @@ impl Core {
             origin: EndUser(origin.name()),
         });
 
-        let targets = self.get_chunk_holder_adults(&target).await;
+        let targets = self.get_adults_who_should_store_chunk(&target).await;
 
         let aggregation = false;
 
@@ -130,7 +130,7 @@ impl Core {
             operation_id
         );
 
-        let targets = self.get_chunk_holder_adults(address.name()).await;
+        let targets = self.get_adults_holding_chunk(address.name()).await;
 
         if targets.is_empty() {
             return self
